==> camitk_3.4.0.orig.tar.gz: camitk-3.4.0-Source/sdk/actions/application/CloseAction.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#ifndef CLOSEACTION_H
#define CLOSEACTION_H

#include <QObject>
#include <Action.h>
#include <Component.h>

/**
 * @ingroup group_sdk_actions_application
 *
 * @brief
 * The CloseAction class allow to close the selected component.
 *
 **/
class CloseAction : public camitk::Action {
    Q_OBJECT

public:
    /// Default Constructor
    CloseAction(camitk::ActionExtension *);

    /// Default Destructor
    virtual ~CloseAction();

    /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
    virtual QWidget * getWidget();

public slots:
    /** this method is automatically called when the action is triggered.
      * It gets all the targets' top level component and close them.
      */
    virtual ApplyStatus apply();
};
#endif // CLOSEACTION_H

==> camitk_4.0.4.orig.tar.gz: camitk-4.0.4-Source/sdk/actions/application/CloseAction.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#ifndef CLOSEACTION_H
#define CLOSEACTION_H

#include <QObject>
#include <Action.h>
#include <Component.h>

/**
 * @ingroup group_sdk_actions_application
 *
 * @brief
 * The CloseAction class closes the selected component.
 *
 **/
class CloseAction : public camitk::Action {
    Q_OBJECT

public:
    /// Default Constructor
    CloseAction(camitk::ActionExtension *);

    /// Default Destructor
    virtual ~CloseAction();

    /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
    virtual QWidget * getWidget();

public slots:
    /** this method is automatically called when the action is triggered.
      * It gets all the targets' top level component and close them.
      */
    virtual ApplyStatus apply();
};
#endif // CLOSEACTION_H
